@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -27,6 +25,7 @@ import shutil
 import socket
 import sys
 from .firefox_binary import FirefoxBinary
+from .service import Service
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.firefox.extension_connection import ExtensionConnection
 from selenium.webdriver.firefox.firefox_profile import FirefoxProfile
@@ -39,7 +38,7 @@ class WebDriver(RemoteWebDriver):
     NATIVE_EVENTS_ALLOWED = sys.platform != "darwin"
 
     def __init__(self, firefox_profile=None, firefox_binary=None, timeout=30,
-                 capabilities=None, proxy=None):
+                 capabilities=None, proxy=None, executable_path='wires'):
 
         self.binary = firefox_binary
         self.profile = firefox_profile
@@ -50,20 +49,36 @@ class WebDriver(RemoteWebDriver):
         self.profile.native_events_enabled = (
             self.NATIVE_EVENTS_ALLOWED and self.profile.native_events_enabled)
 
-        if self.binary is None:
-            self.binary = FirefoxBinary()
-
         if capabilities is None:
             capabilities = DesiredCapabilities.FIREFOX
 
-        if proxy is not None:
-            proxy.add_to_capabilities(capabilities)
+        if "marionette" in capabilities and capabilities['marionette'] is True:
+            # Let's use Marionette! WOOOOHOOOOO!
+            if "binary" in capabilities:
+                self.binary = capabilities["binary"]
+            self.service = Service(executable_path, firefox_binary=self.binary)
+            self.service.start()
 
-        RemoteWebDriver.__init__(self,
+            RemoteWebDriver.__init__(self,
+                command_executor=self.service.service_url,
+                desired_capabilities=capabilities,
+                keep_alive=True)
+
+        else:
+            # Oh well... sometimes the old way is the best way.
+            if self.binary is None:
+                self.binary = FirefoxBinary()
+
+            if proxy is not None:
+                proxy.add_to_capabilities(capabilities)
+
+            RemoteWebDriver.__init__(self,
             command_executor=ExtensionConnection("127.0.0.1", self.profile,
             self.binary, timeout),
             desired_capabilities=capabilities,
             keep_alive=True)
+
+
         self._is_remote = False
 
     def quit(self):
@@ -74,13 +89,15 @@ class WebDriver(RemoteWebDriver):
             # Happens if Firefox shutsdown before we've read the response from
             # the socket.
             pass
-        self.binary.kill()
-        try:
-            shutil.rmtree(self.profile.path)
-            if self.profile.tempfolder is not None:
-                shutil.rmtree(self.profile.tempfolder)
-        except Exception as e:
-            print(str(e))
+        if "marionette" in self.capabilities and self.capabilities['marionette'] is True:
+            self.service.stop()
+        else:
+            try:
+                shutil.rmtree(self.profile.path)
+                if self.profile.tempfolder is not None:
+                    shutil.rmtree(self.profile.tempfolder)
+            except Exception as e:
+                print(str(e))
 
     @property
     def firefox_profile(self):
