@@ -138,6 +138,9 @@ class WebDriver(object):
         self.session_id = response['sessionId']
         self.capabilities = response['value']
 
+        # Quick check to see if we have a W3C Compliant browser
+        self.w3c = "takesElementScreenshot" in self.capabilities
+
     def _wrap_value(self, value):
         if isinstance(value, dict):
             converted = {}
@@ -155,7 +158,7 @@ class WebDriver(object):
         """
         Creates a web element with the specified element_id.
         """
-        return WebElement(self, element_id)
+        return WebElement(self, element_id, w3c=self.w3c)
 
     def _unwrap_value(self, value):
         if isinstance(value, dict) and ('ELEMENT' in value or 'element-6066-11e4-a52e-4f735466cecf' in value):
@@ -500,7 +503,10 @@ class WebDriver(object):
         """
         Maximizes the current window that webdriver is using
         """
-        self.execute(Command.MAXIMIZE_WINDOW, {"windowHandle": "current"})
+        command = Command.MAXIMIZE_WINDOW
+        if self.w3c:
+            command = Command.W3C_MAXIMIZE_WINDOW
+        self.execute(command, {"windowHandle": "current"})
 
     @property
     def switch_to(self):
@@ -636,7 +642,11 @@ class WebDriver(object):
         :Usage:
             driver.implicitly_wait(30)
         """
-        self.execute(Command.IMPLICIT_WAIT, {'ms': float(time_to_wait) * 1000})
+        if self.w3c:
+            self.execute(Command.SET_TIMEOUTS,
+                         {'ms': float(time_to_wait) * 1000, 'type':'implicit'})
+        else:
+            self.execute(Command.IMPLICIT_WAIT, {'ms': float(time_to_wait) * 1000})
 
     def set_script_timeout(self, time_to_wait):
         """
@@ -649,8 +659,12 @@ class WebDriver(object):
         :Usage:
             driver.set_script_timeout(30)
         """
-        self.execute(Command.SET_SCRIPT_TIMEOUT,
-            {'ms': float(time_to_wait) * 1000})
+        if self.w3c:
+            self.execute(Command.SET_TIMEOUTS,
+                         {'ms': float(time_to_wait) * 1000, 'type':'script'})
+        else:
+            self.execute(Command.SET_SCRIPT_TIMEOUT,
+                         {'ms': float(time_to_wait) * 1000})
 
     def set_page_load_timeout(self, time_to_wait):
         """
@@ -677,17 +691,18 @@ class WebDriver(object):
         """
         if not By.is_valid(by) or not isinstance(value, str):
             raise InvalidSelectorException("Invalid locator values passed in")
-        if by == By.ID:
-            by = By.CSS_SELECTOR
-            value = '[id="%s"]' % value
-        elif by == By.TAG_NAME:
-            by = By.CSS_SELECTOR
-        elif by == By.CLASS_NAME:
-            by = By.CSS_SELECTOR
-            value = ".%s" % value
-        elif by == By.NAME:
-            by = By.CSS_SELECTOR
-            value = '[name="%s"]' % value
+        if self.w3c:
+            if by == By.ID:
+                by = By.CSS_SELECTOR
+                value = '[id="%s"]' % value
+            elif by == By.TAG_NAME:
+                by = By.CSS_SELECTOR
+            elif by == By.CLASS_NAME:
+                by = By.CSS_SELECTOR
+                value = ".%s" % value
+            elif by == By.NAME:
+                by = By.CSS_SELECTOR
+                value = '[name="%s"]' % value
         return self.execute(Command.FIND_ELEMENT,
                              {'using': by, 'value': value})['value']
 
@@ -702,18 +717,18 @@ class WebDriver(object):
         """
         if not By.is_valid(by) or not isinstance(value, str):
             raise InvalidSelectorException("Invalid locator values passed in")
-
-        if by == By.ID:
-            by = By.CSS_SELECTOR
-            value = '[id="%s"]' % value
-        elif by == By.TAG_NAME:
-            by = By.CSS_SELECTOR
-        elif by == By.CLASS_NAME:
-            by = By.CSS_SELECTOR
-            value = ".%s" % value
-        elif by == By.NAME:
-            by = By.CSS_SELECTOR
-            value = '[name="%s"]' % value
+        if self.w3c:
+            if by == By.ID:
+                by = By.CSS_SELECTOR
+                value = '[id="%s"]' % value
+            elif by == By.TAG_NAME:
+                by = By.CSS_SELECTOR
+            elif by == By.CLASS_NAME:
+                by = By.CSS_SELECTOR
+                value = ".%s" % value
+            elif by == By.NAME:
+                by = By.CSS_SELECTOR
+                value = '[name="%s"]' % value
 
         return self.execute(Command.FIND_ELEMENTS,
                              {'using': by, 'value': value})['value']
@@ -777,7 +792,10 @@ class WebDriver(object):
         :Usage:
             driver.set_window_size(800,600)
         """
-        self.execute(Command.SET_WINDOW_SIZE, {'width': int(width), 'height': int(height),
+        command = Command.SET_WINDOW_SIZE
+        if self.w3c:
+            command = Command.W3C_SET_WINDOW_SIZE
+        self.execute(command, {'width': int(width), 'height': int(height),
           'windowHandle': windowHandle})
 
     def get_window_size(self, windowHandle='current'):
@@ -787,8 +805,16 @@ class WebDriver(object):
         :Usage:
             driver.get_window_size()
         """
-        return self.execute(Command.GET_WINDOW_SIZE,
-            {'windowHandle': windowHandle})['value']
+        command = Command.GET_WINDOW_SIZE
+        if self.w3c:
+            command = Command.W3C_GET_WINDOW_SIZE
+        size = self.execute(command,
+            {'windowHandle': windowHandle})
+
+        if size.get('value', None) != None:
+            return size['value']
+        else:
+            return size
 
     def set_window_position(self, x, y, windowHandle='current'):
         """
